==> blesta-5.10.2.zip: blesta/language/tr_tr/navigation.php <==
<?php
/**
 * Navigation
 *
 * @package blesta
 * @subpackage blesta.language.tr_tr
 * @copyright Copyright (c) 2024, Phillips Data, Inc.
 * @license http://www.blesta.com/license/ The Blesta License Agreement
 * @link http://www.blesta.com/ Blesta
 */

$lang['Navigation.getprimary.nav_tools_blacklist'] = 'Kara Liste';
$lang['Navigation.getsearchoptions.packages'] = 'Paket Arama';
$lang['Navigation.getsearchoptions.services'] = 'Hizmet Arama';
$lang['Navigation.getsearchoptions.transactions'] = 'İşlem Arama';
$lang['Navigation.getsearchoptions.invoices'] = 'Fatura Arama';
$lang['Navigation.getsearchoptions.clients'] = 'Müşteri Arama';
$lang['Navigation.getsearchoptions.smart'] = 'Akıllı Arama';
$lang['Navigation.getsystem.nav_marketplace'] = 'Pazar Yeri';
$lang['Navigation.getsystem.nav_help_about'] = 'Blesta Hakkında';
$lang['Navigation.getsystem.nav_help_notes'] = 'Sürüm Notları';
$lang['Navigation.getsystem.nav_help_index'] = 'Kaynaklar';
$lang['Navigation.getsystem.nav_help'] = 'Yardım';
$lang['Navigation.getsystem.nav_upgrade'] = 'Yükseltme Seçenekleri';
$lang['Navigation.getsystem.nav_api'] = 'API Erişimi';
$lang['Navigation.getsystem.nav_staff_groups'] = 'Personel Grupları';
$lang['Navigation.getsystem.nav_staff_manage'] = 'Personel Yönetimi';
$lang['Navigation.getsystem.nav_staff'] = 'Personel';
$lang['Navigation.getsystem.nav_backup_amazon'] = 'Amazon S3';
$lang['Navigation.getsystem.nav_backup_index'] = 'Talep Üzerine';
$lang['Navigation.getsystem.nav_backup_ftp'] = 'Güvenli FTP';
$lang['Navigation.getsystem.nav_backup'] = 'Yedekleme';
$lang['Navigation.getsystem.nav_companies'] = 'Şirketler';
$lang['Navigation.getsystem.nav_automation'] = 'Otomasyon';
$lang['Navigation.getsystem.nav_general_paymenttypes'] = 'Ödeme Türleri';
$lang['Navigation.getsystem.nav_general_license'] = 'Lisans Anahtarı';
$lang['Navigation.getsystem.nav_general_maintenance'] = 'Bakım';
$lang['Navigation.getsystem.nav_general_geoip'] = 'GeoIP Ayarları';
$lang['Navigation.getsystem.nav_general_basic'] = 'Temel Kurulum';
$lang['Navigation.getsystem.nav_general'] = 'Genel';
$lang['Navigation.getcompany.nav_feeds_settings'] = 'Besleme Ayarları';
$lang['Navigation.getcompany.nav_feeds_general'] = 'Genel';
$lang['Navigation.getcompany.nav_feeds'] = 'Veri Akışları';
$lang['Navigation.getcompany.nav_groups'] = 'Müşteri Grupları';
$lang['Navigation.getcompany.nav_plugins'] = 'Eklentiler';
$lang['Navigation.getcompany.nav_currency_active'] = 'Aktif Para Birimleri';
$lang['Navigation.getcompany.nav_currency_currencysetup'] = 'Para Birimi Kurulumu';
$lang['Navigation.getcompany.nav_currencies'] = 'Para Birimleri';
$lang['Navigation.getcompany.nav_clientoptions_requiredfields'] = 'Gerekli Müşteri Alanları';
$lang['Navigation.getcompany.nav_clientoptions_customfields'] = 'Müşteri Özel Alanları';
$lang['Navigation.getcompany.nav_clientoptions_general'] = 'Genel İstemci Ayarları';
$lang['Navigation.getcompany.nav_clientoptions'] = 'Müşteri Seçenekleri';
$lang['Navigation.getcompany.nav_emails_signatures'] = 'İmzalar';
$lang['Navigation.getcompany.nav_emails_templates'] = 'E-posta Şablonları';
$lang['Navigation.getcompany.nav_emails_mail'] = 'Posta Ayarları';
$lang['Navigation.getcompany.nav_emails'] = 'E-postalar';
$lang['Navigation.getcompany.nav_taxes_taxrules'] = 'Vergi Kuralları';
$lang['Navigation.getcompany.nav_taxes_basictax'] = 'Temel Vergi Ayarları';
$lang['Navigation.getcompany.nav_taxes'] = 'Vergiler';
$lang['Navigation.getcompany.nav_gateways'] = 'Ödeme Ağ Geçitleri';
$lang['Navigation.getcompany.nav_messengers_templates'] = 'Mesaj Şablonları';
$lang['Navigation.getcompany.nav_messengers_configuration'] = 'Messenger Yapılandırması';
$lang['Navigation.getcompany.nav_messengers_messengers'] = 'Haberciler';
$lang['Navigation.getcompany.nav_messengers'] = 'Haberciler';
$lang['Navigation.getcompany.nav_modules'] = 'Modüller';
$lang['Navigation.getcompany.nav_billing_acceptedtypes'] = 'Kabul Edilen Ödeme Türleri';
$lang['Navigation.getcompany.nav_billing_coupons'] = 'Kuponlar';
$lang['Navigation.getcompany.nav_billing_notices'] = 'Bildirimler';
$lang['Navigation.getcompany.nav_billing_latefees'] = 'Gecikme Ücretleri';
$lang['Navigation.getcompany.nav_billing_deliverymethods'] = 'Fatura Teslimi';
$lang['Navigation.getcompany.nav_billing_custominvoice'] = 'Fatura Özelleştirme';
$lang['Navigation.getcompany.nav_billing_invoices'] = 'Fatura ve Ücretlendirme Seçenekleri';
$lang['Navigation.getcompany.nav_billing'] = 'Faturalama/Ödeme';
$lang['Navigation.getcompany.nav_automation'] = 'Otomasyon';
$lang['Navigation.getcompany.nav_lookandfeel_customize'] = 'Özelleştirme';
$lang['Navigation.getcompany.nav_lookandfeel_actions'] = 'Eylemler';
$lang['Navigation.getcompany.nav_lookandfeel_navigation'] = 'Navigasyon';
$lang['Navigation.getcompany.nav_lookandfeel_layout'] = 'Düzen';
$lang['Navigation.getcompany.nav_lookandfeel_template'] = 'Şablon';
$lang['Navigation.getcompany.nav_lookandfeel_themes'] = 'Temalar';
$lang['Navigation.getcompany.nav_lookandfeel'] = 'Görünüm ve Hissiyat';
$lang['Navigation.getcompany.nav_general_humanverification'] = 'İnsan Doğrulaması';
$lang['Navigation.getcompany.nav_general_smart_search'] = 'Akıllı Arama';
$lang['Navigation.getcompany.nav_general_marketing'] = 'Pazarlama';
$lang['Navigation.getcompany.nav_general_contacttypes'] = 'İletişim Türleri';
$lang['Navigation.getcompany.nav_general_encryption'] = 'Şifreleme';
$lang['Navigation.getcompany.nav_general_international'] = 'Uluslararasılaştırma';
$lang['Navigation.getcompany.nav_general_localization'] = 'Yerelleştirme';
$lang['Navigation.getcompany.nav_general'] = 'Genel';
$lang['Navigation.getprimarypublic.nav_dashboard'] = 'Ev';
$lang['Navigation.getprimaryclient.nav_return'] = 'Gösterge Tablosuna Dön';
$lang['Navigation.getprimaryclient.nav_contacts_add'] = 'İletişim Ekle';
$lang['Navigation.getprimaryclient.nav_contacts'] = 'İletişim';
$lang['Navigation.getprimaryclient.nav_paymentaccounts_add'] = 'Ödeme Hesabı Ekle';
$lang['Navigation.getprimaryclient.nav_paymentaccounts'] = 'Ödeme Hesapları';
$lang['Navigation.getprimaryclient.nav_services'] = 'Hizmetler';
$lang['Navigation.getprimaryclient.nav_dashboard'] = 'Gösterge Tablosu';
$lang['Navigation.getprimary.nav_settings_system'] = 'Sistem';
$lang['Navigation.getprimary.nav_settings_company'] = 'Şirket';
$lang['Navigation.getprimary.nav_tools_renewals'] = 'Yenileme Kuyruğu';
$lang['Navigation.getprimary.nav_tools_utilities'] = 'Yardımcı Programlar';
$lang['Navigation.getprimary.nav_tools_currency'] = 'Para Birimi Dönüştürme';
$lang['Navigation.getprimary.nav_tools_logs'] = 'Günlükler';
$lang['Navigation.getprimary.nav_tools'] = 'Araçlar';
$lang['Navigation.getprimary.nav_package_options'] = 'Yapılandırılabilir Seçenekler';
$lang['Navigation.getprimary.nav_packages_groups'] = 'Paket Grupları';
$lang['Navigation.getprimary.nav_packages_browse'] = 'Paketlere Gözat';
$lang['Navigation.getprimary.nav_packages'] = 'Paketler';
$lang['Navigation.getprimary.nav_billing_batch'] = 'Toplu İş';
$lang['Navigation.getprimary.nav_billing_printqueue'] = 'Yazdırma Kuyruğu';
$lang['Navigation.getprimary.nav_billing_reports'] = 'Raporlar';
$lang['Navigation.getprimary.nav_billing_services'] = 'Hizmetler';
$lang['Navigation.getprimary.nav_billing_transactions'] = 'İşlemler';
$lang['Navigation.getprimary.nav_billing_quotations'] = 'Alıntılar';
$lang['Navigation.getprimary.nav_billing_invoices'] = 'Faturalar';
$lang['Navigation.getprimary.nav_billing_overview'] = 'Genel Bakış';
$lang['Navigation.getprimary.nav_billing'] = 'Faturalandırma';
$lang['Navigation.getprimary.nav_clients_browse'] = 'Müşterilere Gözat';
$lang['Navigation.getprimary.nav_clients'] = 'Müşteriler';
$lang['Navigation.getprimary.nav_home_dashboard'] = 'Gösterge Tablosu';
$lang['Navigation.getprimary.nav_home'] = 'Ev';
$lang['Navigation.!error.parent_id.valid'] = 'Geçersiz üst gezinti öğesi kimliği';
$lang['Navigation.!error.order.valid'] = 'Sipariş indeksi sayısal bir değer olmalıdır';
$lang['Navigation.!error.action_id.valid'] = 'Geçersiz eylem kimliği';

==> blesta-5.11.4.zip: blesta/language/tr_tr/navigation.php <==
<?php
/**
 * Navigation
 *
 * @package blesta
 * @subpackage blesta.language.tr_tr
 * @copyright Copyright (c) 2025, Phillips Data, Inc.
 * @license http://www.blesta.com/license/ The Blesta License Agreement
 * @link http://www.blesta.com/ Blesta
 */

$lang['Navigation.getprimary.nav_tools_blacklist'] = 'Kara Liste';
$lang['Navigation.getsearchoptions.packages'] = 'Paket Arama';
$lang['Navigation.getsearchoptions.services'] = 'Hizmet Arama';
$lang['Navigation.getsearchoptions.transactions'] = 'İşlem Arama';
$lang['Navigation.getsearchoptions.invoices'] = 'Fatura Arama';
$lang['Navigation.getsearchoptions.clients'] = 'Müşteri Arama';
$lang['Navigation.getsearchoptions.smart'] = 'Akıllı Arama';
$lang['Navigation.getsystem.nav_marketplace'] = 'Pazar Yeri';
$lang['Navigation.getsystem.nav_help_about'] = 'Blesta Hakkında';
$lang['Navigation.getsystem.nav_help_notes'] = 'Sürüm Notları';
$lang['Navigation.getsystem.nav_help_index'] = 'Kaynaklar';
$lang['Navigation.getsystem.nav_help'] = 'Yardım';
$lang['Navigation.getsystem.nav_upgrade'] = 'Yükseltme Seçenekleri';
$lang['Navigation.getsystem.nav_api'] = 'API Erişimi';
$lang['Navigation.getsystem.nav_staff_groups'] = 'Personel Grupları';
$lang['Navigation.getsystem.nav_staff_manage'] = 'Personel Yönetimi';
$lang['Navigation.getsystem.nav_staff'] = 'Personel';
$lang['Navigation.getsystem.nav_backup_amazon'] = 'Amazon S3';
$lang['Navigation.getsystem.nav_backup_index'] = 'Talep Üzerine';
$lang['Navigation.getsystem.nav_backup_ftp'] = 'Güvenli FTP';
$lang['Navigation.getsystem.nav_backup'] = 'Yedekleme';
$lang['Navigation.getsystem.nav_companies'] = 'Şirketler';
$lang['Navigation.getsystem.nav_automation'] = 'Otomasyon';
$lang['Navigation.getsystem.nav_general_paymenttypes'] = 'Ödeme Türleri';
$lang['Navigation.getsystem.nav_general_license'] = 'Lisans Anahtarı';
$lang['Navigation.getsystem.nav_general_maintenance'] = 'Bakım';
$lang['Navigation.getsystem.nav_general_geoip'] = 'GeoIP Ayarları';
$lang['Navigation.getsystem.nav_general_basic'] = 'Temel Kurulum';
$lang['Navigation.getsystem.nav_general'] = 'Genel';
$lang['Navigation.getcompany.nav_feeds_settings'] = 'Besleme Ayarları';
$lang['Navigation.getcompany.nav_feeds_general'] = 'Genel';
$lang['Navigation.getcompany.nav_feeds'] = 'Veri Akışları';
$lang['Navigation.getcompany.nav_groups'] = 'Müşteri Grupları';
$lang['Navigation.getcompany.nav_plugins'] = 'Eklentiler';
$lang['Navigation.getcompany.nav_currency_active'] = 'Aktif Para Birimleri';
$lang['Navigation.getcompany.nav_currency_currencysetup'] = 'Para Birimi Kurulumu';
$lang['Navigation.getcompany.nav_currencies'] = 'Para Birimleri';
$lang['Navigation.getcompany.nav_clientoptions_requiredfields'] = 'Gerekli Müşteri Alanları';
$lang['Navigation.getcompany.nav_clientoptions_customfields'] = 'Müşteri Özel Alanları';
$lang['Navigation.getcompany.nav_clientoptions_general'] = 'Genel İstemci Ayarları';
$lang['Navigation.getcompany.nav_clientoptions'] = 'Müşteri Seçenekleri';
$lang['Navigation.getcompany.nav_emails_signatures'] = 'İmzalar';
$lang['Navigation.getcompany.nav_emails_templates'] = 'E-posta Şablonları';
$lang['Navigation.getcompany.nav_emails_mail'] = 'Posta Ayarları';
$lang['Navigation.getcompany.nav_emails'] = 'E-postalar';
$lang['Navigation.getcompany.nav_taxes_taxrules'] = 'Vergi Kuralları';
$lang['Navigation.getcompany.nav_taxes_basictax'] = 'Temel Vergi Ayarları';
$lang['Navigation.getcompany.nav_taxes'] = 'Vergiler';
$lang['Navigation.getcompany.nav_gateways'] = 'Ödeme Ağ Geçitleri';
$lang['Navigation.getcompany.nav_messengers_templates'] = 'Mesaj Şablonları';
$lang['Navigation.getcompany.nav_messengers_configuration'] = 'Messenger Yapılandırması';
$lang['Navigation.getcompany.nav_messengers_messengers'] = 'Haberciler';
$lang['Navigation.getcompany.nav_messengers'] = 'Haberciler';
$lang['Navigation.getcompany.nav_modules'] = 'Modüller';
$lang['Navigation.getcompany.nav_billing_acceptedtypes'] = 'Kabul Edilen Ödeme Türleri';
$lang['Navigation.getcompany.nav_billing_coupons'] = 'Kuponlar';
$lang['Navigation.getcompany.nav_billing_notices'] = 'Bildirimler';
$lang['Navigation.getcompany.nav_billing_latefees'] = 'Gecikme Ücretleri';
$lang['Navigation.getcompany.nav_billing_deliverymethods'] = 'Fatura Teslimi';
$lang['Navigation.getcompany.nav_billing_custominvoice'] = 'Fatura Özelleştirme';
$lang['Navigation.getcompany.nav_billing_invoices'] = 'Fatura ve Ücretlendirme Seçenekleri';
$lang['Navigation.getcompany.nav_billing'] = 'Faturalama/Ödeme';
$lang['Navigation.getcompany.nav_automation'] = 'Otomasyon';
$lang['Navigation.getcompany.nav_lookandfeel_customize'] = 'Özelleştirme';
$lang['Navigation.getcompany.nav_lookandfeel_actions'] = 'Eylemler';
$lang['Navigation.getcompany.nav_lookandfeel_navigation'] = 'Navigasyon';
$lang['Navigation.getcompany.nav_lookandfeel_layout'] = 'Düzen';
$lang['Navigation.getcompany.nav_lookandfeel_template'] = 'Şablon';
$lang['Navigation.getcompany.nav_lookandfeel_themes'] = 'Temalar';
$lang['Navigation.getcompany.nav_lookandfeel'] = 'Görünüm ve Hissiyat';
$lang['Navigation.getcompany.nav_general_humanverification'] = 'İnsan Doğrulaması';
$lang['Navigation.getcompany.nav_general_smart_search'] = 'Akıllı Arama';
$lang['Navigation.getcompany.nav_general_marketing'] = 'Pazarlama';
$lang['Navigation.getcompany.nav_general_contacttypes'] = 'İletişim Türleri';
$lang['Navigation.getcompany.nav_general_encryption'] = 'Şifreleme';
$lang['Navigation.getcompany.nav_general_international'] = 'Uluslararasılaştırma';
$lang['Navigation.getcompany.nav_general_localization'] = 'Yerelleştirme';
$lang['Navigation.getcompany.nav_general'] = 'Genel';
$lang['Navigation.getprimarypublic.nav_dashboard'] = 'Ev';
$lang['Navigation.getprimaryclient.nav_return'] = 'Gösterge Tablosuna Dön';
$lang['Navigation.getprimaryclient.nav_contacts_add'] = 'İletişim Ekle';
$lang['Navigation.getprimaryclient.nav_contacts'] = 'İletişim';
$lang['Navigation.getprimaryclient.nav_paymentaccounts_add'] = 'Ödeme Hesabı Ekle';
$lang['Navigation.getprimaryclient.nav_paymentaccounts'] = 'Ödeme Hesapları';
$lang['Navigation.getprimaryclient.nav_services'] = 'Hizmetler';
$lang['Navigation.getprimaryclient.nav_dashboard'] = 'Gösterge Tablosu';
$lang['Navigation.getprimary.nav_settings_system'] = 'Sistem';
$lang['Navigation.getprimary.nav_settings_company'] = 'Şirket';
$lang['Navigation.getprimary.nav_tools_renewals'] = 'Yenileme Kuyruğu';
$lang['Navigation.getprimary.nav_tools_utilities'] = 'Yardımcı Programlar';
$lang['Navigation.getprimary.nav_tools_currency'] = 'Para Birimi Dönüştürme';
$lang['Navigation.getprimary.nav_tools_logs'] = 'Günlükler';
$lang['Navigation.getprimary.nav_tools'] = 'Araçlar';
$lang['Navigation.getprimary.nav_package_options'] = 'Yapılandırılabilir Seçenekler';
$lang['Navigation.getprimary.nav_packages_groups'] = 'Paket Grupları';
$lang['Navigation.getprimary.nav_packages_browse'] = 'Paketlere Gözat';
$lang['Navigation.getprimary.nav_packages'] = 'Paketler';
$lang['Navigation.getprimary.nav_billing_batch'] = 'Toplu İş';
$lang['Navigation.getprimary.nav_billing_printqueue'] = 'Yazdırma Kuyruğu';
$lang['Navigation.getprimary.nav_billing_reports'] = 'Raporlar';
$lang['Navigation.getprimary.nav_billing_services'] = 'Hizmetler';
$lang['Navigation.getprimary.nav_billing_transactions'] = 'İşlemler';
$lang['Navigation.getprimary.nav_billing_quotations'] = 'Alıntılar';
$lang['Navigation.getprimary.nav_billing_invoices'] = 'Faturalar';
$lang['Navigation.getprimary.nav_billing_overview'] = 'Genel Bakış';
$lang['Navigation.getprimary.nav_billing'] = 'Faturalandırma';
$lang['Navigation.getprimary.nav_clients_browse'] = 'Müşterilere Gözat';
$lang['Navigation.getprimary.nav_clients'] = 'Müşteriler';
$lang['Navigation.getprimary.nav_home_dashboard'] = 'Gösterge Tablosu';
$lang['Navigation.getprimary.nav_home'] = 'Ev';
$lang['Navigation.!error.parent_id.valid'] = 'Geçersiz üst gezinti öğesi kimliği';
$lang['Navigation.!error.order.valid'] = 'Sipariş indeksi sayısal bir değer olmalıdır';
$lang['Navigation.!error.action_id.valid'] = 'Geçersiz eylem kimliği';
$lang['Navigation.getcompany.nav_html_templates'] = 'HTML Şablonları';
$lang['Navigation.getprimary.nav_tools_provisioning'] = 'Servis Kuyruğu';
